ardt.preprocessors.SignalPreprocessor
=====================================

.. currentmodule:: ardt.preprocessors

.. autoclass:: SignalPreprocessor

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~SignalPreprocessor.__init__
      ~SignalPreprocessor.process_signal
      ~SignalPreprocessor.resolve
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~SignalPreprocessor.context
   
   